#import "RBAppController.h"

@implementation RBAppController

- (id)init {
	if (self = [super init]) {
		floatingWindow = nil;
		windowImage = nil;
		[self setImageName:nil];
	}
	return self;
}

- (void)dealloc {
	[floatingWindow release];
	[windowImage release];
	[self setImageName:nil];
	[super dealloc];
}

- (IBAction)doChooseImageFile:(id)sender {
	NSOpenPanel *op = [NSOpenPanel openPanel];
	unsigned int result = -1;
	
	[op setAllowsMultipleSelection:NO];
	result = [op runModalForDirectory:nil file:nil types:[NSImage imageFileTypes]];
	
	if (result == NSOKButton) {
		[windowImage release];
		windowImage = [[[NSImage alloc] initWithContentsOfFile:[[op filenames] objectAtIndex:0]] retain];
		if (!windowImage) {
			return;
		}
	} else {
		return;
	}

	NSRect imageRect = NSMakeRect(0.0, 0.0, [windowImage size].width, [windowImage size].height);
		
	if (!floatingWindow) {
		floatingWindow = [[[NSWindow alloc] initWithContentRect:imageRect styleMask:NSBorderlessWindowMask backing:NSBackingStoreBuffered defer:nil] retain];
		[floatingWindow setContentView:imageHolderView];
		[floatingWindow setOpaque:NO];
		[floatingWindow setHasShadow:NO];
		[floatingWindow setIgnoresMouseEvents:YES];
		[floatingWindow setAlphaValue:[alphaSlider floatValue]];
		[floatingWindow setLevel:NSPopUpMenuWindowLevel];
		[floatingWindow orderFront:nil];
	}
	
	[imageView setImage:windowImage];
	[self setImageName:[[[op filenames] objectAtIndex:0] lastPathComponent]];
	[self doChangePlacementMode:placementModeButton];
}

- (IBAction)doChangeAlpha:(id)sender {
	[floatingWindow setAlphaValue:[sender floatValue]];
}

- (IBAction)doChangePlacementMode:(id)sender {
	if ([[sender selectedItem] tag] == 0) {
		// center
		float screenWidth = [[NSScreen mainScreen] frame].size.width;
		float screenHeight = [[NSScreen mainScreen] frame].size.height;
		NSRect imageRect = NSMakeRect(screenWidth / 2.0 - [windowImage size].width / 2.0, screenHeight / 2.0 - [windowImage size].height / 2.0, [windowImage size].width, [windowImage size].height);
		[floatingWindow setFrame:imageRect display:NO];
	} else if ([[sender selectedItem] tag] == 1) {
		// stretch to fit
		[floatingWindow setFrame:[[NSScreen mainScreen] frame] display:NO];
	}
}

- (IBAction)doSetMinimumAlpha:(id)sender {
	// useful for recovering the screen when everything gets lost under a full-screen, full-alpha overlay window
	[alphaSlider setFloatValue:0.0];
	[floatingWindow setAlphaValue:0.0];
}

- (IBAction)doSetMaximumAlpha:(id)sender {
	[alphaSlider setFloatValue:1.0];
	[floatingWindow setAlphaValue:1.0];
}

// accessors

- (NSString*)imageName {
	return imageName;
}

- (void)setImageName:(NSString*)newName {
	[newName retain];
	[imageName release];
	imageName = newName;
}

@end
